Struct http_serve::ChunkedReadFile[][src]

pub struct ChunkedReadFile<D: 'static + Send + Buf + From<Vec<u8>> + From<&'static [u8]>, E: 'static + Send + Into<Box<Error + Send + Sync>> + From<Box<Error>>> { /* fields omitted */ }

A HTTP entity created from a std::fs::File which reads the file chunk-by-chunk on a CpuPool.

Methods

impl<D, E> ChunkedReadFile<D, E> where
    D: 'static + Send + Buf + From<Vec<u8>> + From<&'static [u8]>,
    E: 'static + Send + Into<Box<Error + Send + Sync>> + From<Box<Error>>, 
[src]

Creates a new ChunkedReadFile.

read(2) calls will be performed on the supplied pool so that they don't block the tokio reactor thread on local disk I/O. Note that File::open and this constructor (specifically, its call to fstat(2)) may also block, so they typically shouldn't be called on the tokio reactor either.