Struct http_serve::StreamingBodyBuilder [−][src]
pub struct StreamingBodyBuilder { /* fields omitted */ }Expand description
A builder returned by streaming_body.
Implementations
Sets the size of a data chunk.
This is a compromise between memory usage and efficiency. The default of 4096 is usually fine; increasing will likely only be noticeably more efficient when compression is off.
Sets the gzip compression level. Defaults to 6.
gzip_level should be an integer between 0 and 9 (inclusive).
0 means no compression; 9 gives the best compression (but most CPU usage).
This is only effective if the client supports compression.